@@ -19,6 +19,8 @@ var credits =
                               ],
         [ "Norbert K.",       "Modify > Break out Gap<br>"
                               ],
+        [ "Pete Vickerstaff", "Misc > Draw > Line break symbol from 2 points<br>"
+                              ],
         [ "Robert S.",        "Direct distance entry<br>" +
                               "Selecting overlapping entities<br>" +
                               "Polyline area calculation<br>" +
@@ -44,32 +46,44 @@ var credits =
                               "Info > Arc/Circle/Ellipse Area<br>" +
                               "Custom linetype support, loading .lin files<br>"
                               ],
-        [ "Stephen Casner",   "Misc > Select > By Color"
+        [ "Stephen Casner",   "Misc > Select > By Color<br>"
                               ],
         [ "Tamas Tevesz",     "Port to FreeBSD<br>" +
                               "Various improvements and fixes<br>"
                               ],
-        [ "Weston Schmidt",   "Draw > Dimension > Per-dimension scaling<br>"
+        [ "Weston Schmidt",   "Draw > Dimension > Per-dimension scaling<br>" +
+                              "Script inclusion path improvements<br>"
                               ],
     ],
     [
         qsTr("Hatch Patterns"),
-        [ "John Hyslop",         "BLOCKS-01, BLOCKS-01, " +
+        [ "John Hyslop",         "AR-CONC-01, " +
+                                 "BARBWIRE, " +
+                                 "BLOCKS-01, BLOCKS-02, " +
                                  "BOXJOIN-01, BOXJOIN-02, " +
                                  "BOX-OVERLAP, " +
-                                 "CELTIC-01, CELTIC-02, " +
+                                 "BUBBLES-01, BUBBLES-02, BUBBLES-03, " +
+                                 "CELTIC-01, CELTIC-02, CELTIC-03, CELTIC-04, " +
                                  "CIRCLES, CIRCLES-02, " +
                                  "EXPLOSION, " +
+                                 "GRAVEL-01, " +
+                                 "HATCH-DOTS, HATCH-SQRS, " +
                                  "HEXAGONS, " +
                                  "HEXJOIN-01, HEXJOIN-02, " +
                                  "HOLLY, " +
                                  "LATTICE-01, LATTICE-02, LATTICE-03, " +
-                                 "LATTICE-04, LATTICE-05, LATTICE-06, " +
+                                 "LATTICE-04, LATTICE-05, LATTICE-06, LATTICE-07, " +
+                                 "LEAF-01, LEAF-02, LEAF-03, " +
+                                 "LOOPLINKS, " +
                                  "MAZE-01, MAZE-02, " +
                                  "QCAD-LOGO, " +
+                                 "REDBACK, " +
                                  "SCAFFOLD, " +
                                  "SQUIGGLE-01, SQUIGGLE-02, " +
-                                 "TRI-OVERLAP"
+                                 "TRI-OVERLAP, " +
+                                 "WEATHERBOARD, WEAVING, " +
+                                 "WIRE-FENCE, " +
+                                 "XMASTREE-01, XMASTREE-02"
                                  ],
     ],
     [
